Cookbook
========

This section contains practical examples and instructions
for various topics related to the library. This section
aims to provide ideas for your project and show how to
do more specific things.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   settings
   conditions
   bigger_applications
   robust_applications
   controlling_runtime
   fastapi
   django
   testing
